@@ -5,7 +5,8 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
-#include <collectionindexingjob.h>
+#include "collectionindexingjob.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <Akonadi/Collection>
 #include <Akonadi/CollectionFetchJob>
@@ -94,7 +95,7 @@ private Q_SLOTS:
         fetchJob->exec();
         const Akonadi::Collection::List lstCols = fetchJob->collections();
         for (const Akonadi::Collection &col : lstCols) {
-            if (col.name() == QLatin1String("foo")) {
+            if (col.name() == "foo"_L1) {
                 itemCollection = col;
             }
         }
